netapp_ontap.models.nvme_subsystem_subsystem_maps API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_subsystem_subsystem_maps`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeSubsystemSubsystemMapsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemSubsystemMaps object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `anagrpid GET`

    The Asymmetric Namespace Access Group ID (ANAGRPID) of the NVMe namespace.
    The format for an ANAGRPIP is 8 hexadecimal digits (zero-filled) followed by a lower case "h".

    Example: 00103050h

  `links GET`

    The links field of the nvme_subsystem_subsystem_maps.

  `namespace GET POST PATCH`

    The namespace field of the nvme_subsystem_subsystem_maps.

  `nsid GET`

    The NVMe namespace identifier. This is an identifier used by an NVMe controller to provide access to the NVMe namespace.
    The format for an NVMe namespace identifier is 8 hexadecimal digits (zero-filled) followed by a lower case "h".

    Example: 00000001h